@@ -193,7 +193,7 @@ func (rb *Base) MakeMultiPartRequest(ctx context.Context, apiKey, path string, p
 
 // MakeRequest will make a request to the Stripe API with the specific variables given to it
 func (rb *Base) MakeRequest(ctx context.Context, apiKey, path string, params *RequestParameters, errOnStatus bool) ([]byte, error) {
-	data, err := rb.buildDataForRequest(params)
+	data, err := rb.BuildDataForRequest(params)
 	if err != nil {
 		return []byte{}, err
 	}
@@ -274,13 +274,14 @@ func (rb *Base) Confirm() (bool, error) {
 	return rb.confirmCommand()
 }
 
+// BuildDataForRequest builds request payload
 // Note: We converted to using two arrays to track keys and values, with our own
 // implementation of Go's url.Values Encode function due to our query parameters being
 // order sensitive for API requests involving arrays like `items` for `/v1/orders`.
 // Go's url.Values uses Go's map, which jumbles the key ordering, and their Encode
 // implementation sorts keys by alphabetical order, but this doesn't work for us since
 // some API endpoints have required parameter ordering. Yes, this is hacky, but it works.
-func (rb *Base) buildDataForRequest(params *RequestParameters) (string, error) {
+func (rb *Base) BuildDataForRequest(params *RequestParameters) (string, error) {
 	keys := []string{}
 	values := []string{}
 
